//------------------------------------------------------------------------------
// Lamp : Open source game middleware
// Copyright (C) 2004  Junpei Ohtani ( Email : junpee@users.sourceforge.jp )
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//------------------------------------------------------------------------------

/** @file
 * テキストメモリリーダヘッダ
 * @author Junpee
 */

#ifndef TEXT_MEMORY_READER_H_
#define TEXT_MEMORY_READER_H_

#include <Core/InputOutput/TextReader.h>
#include <Core/InputOutput/MemoryInputStream.h>

namespace Lamp{

//------------------------------------------------------------------------------
/**
 * テキストメモリリーダ
 */
class TextMemoryReader : public TextReader{
public:
	/**
	 * コンストラクタ
	 * @param buffer 読み込むバッファ。バッファの解放は行いません。
	 * @param size バッファのサイズ
	 */
	TextMemoryReader(const char* buffer, int size){
		stream_ = new MemoryInputStream(buffer, size);
	}

	/**
	 * テキストメモリリーダの複製
	 * @return 複製されたテキストメモリリーダ
	 */
	virtual TextMemoryReader* cloneTextMemoryReader(){
		TextMemoryReader* textMemoryReader =
			new TextMemoryReader(getBufferSize());
		textMemoryReader->stream_ = stream_->cloneInputStream();
		copyTextReaderData(textMemoryReader);
		return textMemoryReader;
	}

	/**
	 * テキストリーダの複製
	 * @return 複製されたテキストリーダ
	 */
	virtual TextReader* cloneTextReader(){ return cloneTextMemoryReader(); }

protected:
	/**
	 * コンストラクタ
	 * @param bufferSize バッファサイズ
	 */
	TextMemoryReader(int bufferSize) : TextReader(bufferSize){}

};

//------------------------------------------------------------------------------
} // End of namespace Lamp
#endif // End of TEXT_MEMORY_READER_H_
//------------------------------------------------------------------------------
